@@ -23,6 +23,7 @@ import (
 	"golang.org/x/crypto/ssh/agent"
 
 	"github.com/umputun/spot/pkg/config"
+	"github.com/umputun/spot/pkg/runner/mocks"
 )
 
 func Test_main(t *testing.T) {
@@ -74,7 +75,7 @@ func Test_runCompleted(t *testing.T) {
 			Dbg: true,
 		}
 		st := time.Now()
-		logOut := captureStdout(t, func() {
+		logOut := captureStdout(func() {
 			err := run(opts)
 			require.NoError(t, err)
 		})
@@ -97,7 +98,7 @@ func Test_runCompleted(t *testing.T) {
 			},
 			Dbg: true,
 		}
-		logOut := captureStdout(t, func() {
+		logOut := captureStdout(func() {
 			err := run(opts)
 			require.NoError(t, err)
 		})
@@ -124,7 +125,7 @@ func Test_runCompleted(t *testing.T) {
 			Dbg: true,
 		}
 		st := time.Now()
-		logOut := captureStdout(t, func() {
+		logOut := captureStdout(func() {
 			err := run(opts)
 			require.NoError(t, err)
 		})
@@ -148,7 +149,7 @@ func Test_runCompleted(t *testing.T) {
 			},
 			Dbg: true,
 		}
-		logOut := captureStdout(t, func() {
+		logOut := captureStdout(func() {
 			err := run(opts)
 			require.NoError(t, err)
 		})
@@ -170,7 +171,7 @@ func Test_runCompleted(t *testing.T) {
 			Dbg:     true,
 			Verbose: []bool{true},
 		}
-		logOut := captureStdout(t, func() {
+		logOut := captureStdout(func() {
 			err := run(opts)
 			require.NoError(t, err)
 		})
@@ -193,7 +194,7 @@ func Test_runCompletedSimplePlaybook(t *testing.T) {
 		Dbg:          true,
 	}
 	st := time.Now()
-	logOut := captureStdout(t, func() {
+	logOut := captureStdout(func() {
 		err := run(opts)
 		require.NoError(t, err)
 	})
@@ -212,7 +213,7 @@ func Test_runAdhoc(t *testing.T) {
 		Dbg:     true,
 	}
 	opts.PositionalArgs.AdHocCmd = "echo hello"
-	logOut := captureStdout(t, func() {
+	logOut := captureStdout(func() {
 		err := run(opts)
 		require.NoError(t, err)
 	})
@@ -233,7 +234,7 @@ func Test_runCompletedSeveralTasks(t *testing.T) {
 	}
 
 	st := time.Now()
-	logOut := captureStdout(t, func() {
+	logOut := captureStdout(func() {
 		err := run(opts)
 		require.NoError(t, err)
 	})
@@ -257,7 +258,7 @@ func Test_runCompletedAllTasks(t *testing.T) {
 	}
 
 	st := time.Now()
-	logOut := captureStdout(t, func() {
+	logOut := captureStdout(func() {
 		err := run(opts)
 		require.NoError(t, err)
 	})
@@ -490,7 +491,7 @@ func TestRunWithCustomTempDir(t *testing.T) {
 		Dbg:          true,
 	}
 
-	logOut := captureStdout(t, func() {
+	logOut := captureStdout(func() {
 		err := run(opts)
 		require.NoError(t, err)
 	})
@@ -1092,9 +1093,6 @@ func startTestContainer(t *testing.T) (hostAndPort string, teardown func()) {
 		Image:        "lscr.io/linuxserver/openssh-server:latest",
 		ExposedPorts: []string{"2222/tcp"},
 		WaitingFor:   wait.NewLogStrategy("done.").WithStartupTimeout(time.Second * 60),
-		Files: []testcontainers.ContainerFile{
-			{HostFilePath: "testdata/test_ssh_key.pub", ContainerFilePath: "/authorized_key"},
-		},
 		Env: map[string]string{
 			"PUBLIC_KEY": string(pubKey),
 			"USER_NAME":  "test",
@@ -1107,7 +1105,6 @@ func startTestContainer(t *testing.T) (hostAndPort string, teardown func()) {
 	})
 	require.NoError(t, err)
 
-	require.NoError(t, err)
 	port, err := container.MappedPort(ctx, "2222")
 	require.NoError(t, err)
 	host, err := container.Host(ctx)
@@ -1116,7 +1113,7 @@ func startTestContainer(t *testing.T) (hostAndPort string, teardown func()) {
 }
 
 // captureStdout captures everything written to stdout within the function fn
-func captureStdout(t *testing.T, fn func()) string {
+func captureStdout(fn func()) string {
 	// keep backup of the real stdout
 	old := os.Stdout
 	defer func() { os.Stdout = old }()
@@ -1131,3 +1128,75 @@ func captureStdout(t *testing.T, fn func()) string {
 	out, _ := io.ReadAll(r)
 	return string(out)
 }
+
+func Test_resolveTaskNames(t *testing.T) {
+	allTasks := []config.Task{
+		{Name: "deploy-app", Tags: []string{"deploy", "prod"}},
+		{Name: "deploy-db", Tags: []string{"deploy", "prod"}},
+		{Name: "test", Tags: []string{"test"}},
+		{Name: "lint"},
+	}
+
+	pbMock := &mocks.PlaybookMock{
+		AllTasksFunc: func() []config.Task { return allTasks },
+		TasksByTagFunc: func(tag string) []string {
+			var res []string
+			for _, t := range allTasks {
+				for _, tt := range t.Tags {
+					if strings.EqualFold(tt, tag) {
+						res = append(res, t.Name)
+						break
+					}
+				}
+			}
+			return res
+		},
+	}
+
+	t.Run("exact name match", func(t *testing.T) {
+		result, err := resolveTaskNames([]string{"deploy-app"}, pbMock)
+		require.NoError(t, err)
+		assert.Equal(t, []string{"deploy-app"}, result)
+	})
+
+	t.Run("tag match", func(t *testing.T) {
+		result, err := resolveTaskNames([]string{"deploy"}, pbMock)
+		require.NoError(t, err)
+		assert.Equal(t, []string{"deploy-app", "deploy-db"}, result)
+	})
+
+	t.Run("exact name takes priority over tag", func(t *testing.T) {
+		result, err := resolveTaskNames([]string{"test"}, pbMock)
+		require.NoError(t, err)
+		assert.Equal(t, []string{"test"}, result)
+	})
+
+	t.Run("mixed name and tag", func(t *testing.T) {
+		result, err := resolveTaskNames([]string{"lint", "deploy"}, pbMock)
+		require.NoError(t, err)
+		assert.Equal(t, []string{"lint", "deploy-app", "deploy-db"}, result)
+	})
+
+	t.Run("no match returns error", func(t *testing.T) {
+		_, err := resolveTaskNames([]string{"unknown"}, pbMock)
+		assert.EqualError(t, err, `task or tag "unknown" not found`)
+	})
+
+	t.Run("case insensitive name match", func(t *testing.T) {
+		result, err := resolveTaskNames([]string{"Deploy-App"}, pbMock)
+		require.NoError(t, err)
+		assert.Equal(t, []string{"deploy-app"}, result)
+	})
+
+	t.Run("deduplicates name and tag overlap", func(t *testing.T) {
+		result, err := resolveTaskNames([]string{"deploy-app", "deploy"}, pbMock)
+		require.NoError(t, err)
+		assert.Equal(t, []string{"deploy-app", "deploy-db"}, result)
+	})
+
+	t.Run("deduplicates overlapping tags", func(t *testing.T) {
+		result, err := resolveTaskNames([]string{"deploy", "prod"}, pbMock)
+		require.NoError(t, err)
+		assert.Equal(t, []string{"deploy-app", "deploy-db"}, result)
+	})
+}
