@@ -884,6 +884,29 @@ func Test_execLine(t *testing.T) {
 		assert.Equal(t, []string{"line1", "replaced line", "line3"}, out)
 	})
 
+	t.Run("line command replace with anchored match", func(t *testing.T) {
+		testFile := "/tmp/test_line_anchored.txt"
+		_, err := sess.Run(ctx, fmt.Sprintf("echo -e 'port=3000\\nhost=old\\nhostname=keep' > %s", testFile), nil)
+		require.NoError(t, err)
+		defer sess.Run(ctx, fmt.Sprintf("rm -f %s", testFile), nil)
+
+		ec := execCmd{
+			exec: sess,
+			tsk:  &config.Task{Name: "test"},
+			cmd: config.Cmd{
+				Line: config.LineInternal{File: testFile, Match: "^host=", Replace: "host=new-value"},
+				Name: "test line replace anchored",
+			},
+		}
+		resp, err := ec.Line(ctx)
+		require.NoError(t, err)
+		assert.Equal(t, " {line: /tmp/test_line_anchored.txt, replace: ^host=}", resp.details)
+
+		out, err := sess.Run(ctx, fmt.Sprintf("cat %s", testFile), nil)
+		require.NoError(t, err)
+		assert.Equal(t, []string{"port=3000", "host=new-value", "hostname=keep"}, out)
+	})
+
 	t.Run("line command append", func(t *testing.T) {
 		// create a test file without the pattern
 		testFile := "/tmp/test_line_append.txt"
@@ -1115,7 +1138,7 @@ func Test_execCmdWithTmp(t *testing.T) {
 		resp, err = ec.Script(ctx)
 		require.NoError(t, err)
 		assert.Contains(t, wr.String(), "/tmp/inventory.txt")
-		assert.Contains(t, wr.String(), "> -rw-r--r-- ")
+		assert.Regexp(t, "> -rw-[r-][w-]-[r-][w-]-", wr.String())
 
 		// check if tmp dir removed
 		wr.Reset()
@@ -1150,7 +1173,7 @@ func Test_execCmdWithTmp(t *testing.T) {
 		resp, err = ec.Script(ctx)
 		require.NoError(t, err)
 		assert.Contains(t, wr.String(), "/tmp/inventory.txt")
-		assert.Contains(t, wr.String(), "> -rwxr-xr-x ", "file should be executable")
+		assert.Regexp(t, "> -rwx[r-][w-]x[r-][w-]x", wr.String(), "file should be executable")
 
 		// check if tmp dir removed
 		wr.Reset()
